# s comment -*-coding: iso-8859-1;-*-
S'executa quan s'invoca bash.
END
S'executa quan s'invoca bash.
END
print <<"EOF";
# valors per a usuaris catalanoparlants
# settings for catalan speaking users
#

LANG=$LOCALE
export LANG

#LC_MESSAGES=$LOCALE
#LC_CTYPE=$LOCALE
#export LC_MESSAGES LC_CTYPE

if [ -d /usr/X11R6/lib/X11/nls ]; then
    XNLSPATH=/usr/X11R6/lib/X11/nls
    export XNLSPATH
fi

LESSCHARSET=latin1

# Obtingut de http://members.xoom.com/sromero/linux/castell.html
export MM_CHARSET=$ENCODING	# per a usar latin1 en els mails
EOF
